# Spatial Index Test Data

This repo contains the files used for tests in [Spatial Index](https://bbpgitlab.epfl.ch/hpc/spatial-index).

Both the source files and the index generated by them are included.
The indexes can be regenerated using the `generate.sh` scripts present in this repo, one for each index type.

This repo is used as a submodule in the [Spatial Index](https://bbpgitlab.epfl.ch/hpc/spatial-index) repo.

